@@ -265,7 +265,7 @@ def getClassFullName(classItem):
 
 def decode(value):
     data = chardet.detect(value)
-    encoding = data["encoding"]
+    encoding = data["encoding"] or "utf8"
     return value.decode(encoding)
 
 
